@@ -171,7 +171,7 @@ list__process_line (char     *line,
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
 
-	comm->file_list = g_list_prepend (comm->file_list, fdata);
+	fr_command_add_file (comm, fdata);
 }
 
 
