@@ -53,6 +53,8 @@ mktime_from_string (char *month,
 				   "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 	struct tm     tm = {0, };
 
+	tm.tm_isdst = -1;
+
 	if (month != NULL) {
 		int i;
 		for (i = 0; i < 12; i++)
@@ -68,7 +70,7 @@ mktime_from_string (char *month,
 	        	time_t      now;
         		struct tm  *now_tm;
 
-	  		tm.tm_hour = atoi (fields[0]) - 1;
+	  		tm.tm_hour = atoi (fields[0]);
 	  		tm.tm_min = atoi (fields[1]);
 	  
 	  		now = time(NULL);
@@ -139,7 +141,7 @@ list__process_line (char     *line,
 	if (*fdata->name == 0)
 		file_data_free (fdata);
 	else 
-		comm->file_list = g_list_prepend (comm->file_list, fdata);
+		fr_command_add_file (comm, fdata);
 }
 
 
